@@ -1,7 +1,8 @@
 #!/usr/bin/python3
 
 from urllib.parse import urlparse
-from lintian_brush.fixer import control, report_result, fixed_lintian_tag
+
+from lintian_brush.fixer import control, fixed_lintian_tag, report_result
 
 HOST_TO_VCS = {
     'github.com': 'Git',
