@@ -18,46 +18,46 @@
 
 """Utility for dropping unnecessary constraints."""
 
-from contextlib import suppress
 import json
 import logging
 import os
 import sys
-from typing import List, Tuple, Optional, Dict, Callable, Union
+from contextlib import suppress
+from typing import Callable, Dict, List, Optional, Tuple, Union
 
-from breezy.commit import PointlessCommit, NullCommitReporter
+from breezy.commit import NullCommitReporter, PointlessCommit
 from breezy.workingtree import WorkingTree
-
-from debmutate.control import PkgRelation
-from debmutate.deb822 import ChangeConflict
-from debmutate.debhelper import MaintscriptEditor
-from debmutate.reformatting import FormattingUnpreservable
-
-from debian.changelog import Version
-from debian.deb822 import Deb822Dict
-
 from debmutate.control import (
     ControlEditor,
-    parse_relations,
+    PkgRelation,
     format_relations,
     guess_template_type,
+    parse_relations,
 )
-
+from debmutate.deb822 import ChangeConflict
+from debmutate.debhelper import MaintscriptEditor
 from debmutate.reformatting import (
-    check_generated_file,
+    FormattingUnpreservable,
     GeneratedFile,
+    check_generated_file,
 )
 
-from .changelog import add_changelog_entry
-from . import (
-    get_committer,
-    control_files_in_root,
-    control_file_present,
-    NotDebianPackage,
-    is_debcargo_package,
-    )
-from .debhelper import drop_obsolete_maintscript_entries
+from debian.deb822 import Deb822Dict
+from debian.debian_support import Version
 
+from . import (
+    NotDebianPackage,
+    control_file_present,
+    control_files_in_root,
+    get_committer,
+    is_debcargo_package,
+)
+from .changelog import add_changelog_entry
+from .debhelper import drop_obsolete_maintscript_entries
+from .svp import (
+    report_fatal,
+    svp_enabled,
+)
 
 DEFAULT_VALUE_MULTIARCH_HINT = 30
 
@@ -138,8 +138,8 @@ class ReplaceTransition(Action):
 
     def __str__(self):
         return (
-            "Replace dependency on transitional package %s "
-            "with replacement %s" % (
+            "Replace dependency on transitional package {} "
+            "with replacement {}".format(
                 PkgRelation.str(self.rel), name_list([
                     PkgRelation.str(p) for p in self.replacement])))
 
@@ -256,8 +256,8 @@ def _package_build_essential(package: str, release: str) -> bool:
 
 
 def _fetch_transitions(release: str) -> Dict[str, str]:
-    from .udd import connect_udd_mirror
     from .dummy_transitional import find_dummy_transitional_packages
+    from .udd import connect_udd_mirror
 
     ret = {}
     conn = connect_udd_mirror()
@@ -597,7 +597,7 @@ def _scrub_obsolete(
         if wt.has_filename(os.path.join(debian_path, "debcargo.toml")):
             control_actions = []
         else:
-            raise NotDebianPackage(wt, debian_path) from exc
+            raise NotDebianPackage(wt.abspath(debian_path)) from exc
 
     maintscript_removed = []
     for path, removed in update_maintscripts(
@@ -643,9 +643,7 @@ def scrub_obsolete(
         allow_reformatting: bool = False,
         keep_minimum_depends_versions: bool = False,
         transitions: Optional[Dict[str, str]] = None) -> ScrubObsoleteResult:
-    """Scrub obsolete entries.
-    """
-
+    """Scrub obsolete entries."""
     if control_files_in_root(wt, subpath):
         debian_path = subpath
     else:
@@ -665,9 +663,10 @@ def scrub_obsolete(
     changelog_path = os.path.join(debian_path, "changelog")
 
     if update_changelog is None:
-        from .detect_gbp_dch import guess_update_changelog
         from debian.changelog import Changelog
 
+        from .detect_gbp_dch import guess_update_changelog
+
         with wt.get_file(changelog_path) as f:
             cl = Changelog(f, max_blocks=1)
 
@@ -715,10 +714,11 @@ def scrub_obsolete(
     return result
 
 
-def versions_dict():
-    import lintian_brush
+def versions_dict() -> dict[str, str]:
     import debmutate
+
     import debian
+    import lintian_brush
     return {
         "lintian-brush": lintian_brush.version_string,
         "debmutate": debmutate.version_string,
@@ -726,16 +726,6 @@ def versions_dict():
     }
 
 
-def report_fatal(code: str, description: str) -> None:
-    if os.environ.get('SVP_API') == '1':
-        with open(os.environ['SVP_RESULT'], 'w') as f:
-            json.dump({
-                'result_code': code,
-                'versions': versions_dict(),
-                'description': description}, f)
-    logging.fatal('%s', description)
-
-
 def report_okay(code: str, description: str) -> None:
     if os.environ.get('SVP_API') == '1':
         with open(os.environ['SVP_RESULT'], 'w') as f:
@@ -748,17 +738,18 @@ def report_okay(code: str, description: str) -> None:
 
 def main():  # noqa: C901
     import argparse
+
     import breezy  # noqa: E402
     from breezy.errors import NotBranchError
 
     breezy.initialize()  # type: ignore
-    import breezy.git  # noqa: E402
     import breezy.bzr  # noqa: E402
-
+    import breezy.git  # noqa: E402
     from breezy.workspace import (
-        check_clean_tree,
         WorkspaceDirty,
-        )
+        check_clean_tree,
+    )
+
     from . import (
         version_string,
     )
@@ -885,11 +876,13 @@ def main():  # noqa: C901
             allow_reformatting = False
 
         if is_debcargo_package(wt, subpath):
-            report_fatal("nothing-to-do", "Package uses debcargo")
+            report_fatal(
+                versions_dict(), "nothing-to-do", "Package uses debcargo")
             return 1
         elif not control_file_present(wt, subpath):
             report_fatal(
-                "missing-control-file", "Unable to find debian/control")
+                versions_dict(), "missing-control-file",
+                "Unable to find debian/control")
             return 1
 
         try:
@@ -903,7 +896,7 @@ def main():  # noqa: C901
             )
         except FormattingUnpreservable as e:
             report_fatal(
-                "formatting-unpreservable",
+                versions_dict(), "formatting-unpreservable",
                 "unable to preserve formatting while editing %s" % e.path,
             )
             if hasattr(e, 'diff'):  # debmutate >= 0.64
@@ -911,18 +904,23 @@ def main():  # noqa: C901
             return 1
         except GeneratedFile as e:
             report_fatal(
-                "generated-file", "unable to edit generated file: %r" % e
+                versions_dict(), "generated-file",
+                "unable to edit generated file: %r" % e
             )
             return 1
         except NotDebianPackage:
-            report_fatal('not-debian-package', 'Not a Debian package.')
+            report_fatal(
+                versions_dict(), 'not-debian-package', 'Not a Debian package.')
             return 1
         except ChangeConflict as e:
             report_fatal(
-                'change-conflict', 'Generated file changes conflict: %s' % e)
+                versions_dict(), 'change-conflict',
+                'Generated file changes conflict: %s' % e)
             return 1
         except UddError as e:
-            report_fatal('udd-error', f'Error communicating with UDD: {e}')
+            report_fatal(
+                versions_dict(), 'udd-error',
+                f'Error communicating with UDD: {e}')
             return 1
 
     if not result:
@@ -933,7 +931,7 @@ def main():  # noqa: C901
     if result.changelog_behaviour:
         debian_context['changelog'] = result.changelog_behaviour.json()
 
-    if os.environ.get("SVP_API") == "1":
+    if svp_enabled():
         with open(os.environ["SVP_RESULT"], "w") as f:
             json.dump({
                 "description": "Remove constraints unnecessary since %s."
