@@ -17,16 +17,11 @@
 
 """Tests for lintian_brush."""
 
-from datetime import datetime
 import os
 import re
 import sys
-from typing import Type, Callable, Any
-
-from debian.changelog import (
-    Changelog,
-    Version,
-)
+from datetime import datetime
+from typing import Any, Callable, Type
 
 from breezy.config import GlobalStack
 from breezy.tests import (
@@ -34,7 +29,12 @@ from breezy.tests import (
     TestCaseWithTransport,
 )
 
+from debian.changelog import (
+    Changelog,
+)
+from debian.debian_support import Version
 from lintian_brush import (
+    FailedPatchManipulation,
     FixerFailed,
     FixerResult,
     FixerScriptFailed,
@@ -42,25 +42,22 @@ from lintian_brush import (
     NotDebianPackage,
     PythonScriptFixer,
     ScriptFixer,
-    FailedPatchManipulation,
     UnsupportedCertainty,
     available_lintian_fixers,
     certainty_sufficient,
-    min_certainty,
     certainty_to_confidence,
     confidence_to_certainty,
     get_committer,
     increment_version,
+    min_certainty,
     only_changes_last_changelog_block,
     parse_script_fixer_output,
     run_lintian_fixer,
     run_lintian_fixers,
     select_fixers,
     version_string,
-    ManyResult,
 )
 
-
 CHANGELOG_FILE = (
     "debian/changelog",
     """\
@@ -595,7 +592,7 @@ Arch: all
 class IncrementVersionTests(TestCase):
     def assertVersion(self, expected, start):
         v = Version(start)
-        increment_version(v)
+        v = increment_version(v)
         self.assertEqual(Version(expected), v)
 
     def test_full(self):
@@ -652,7 +649,7 @@ blah (0.1) unstable; urgency=medium
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(
             only_changes_last_changelog_block(
-                tree, tree.basis_tree(), "debian/changelog", changes
+                tree, tree.basis_tree(), "debian/changelog", list(changes)
             )
         )
 
@@ -679,7 +676,7 @@ Arch: all
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(
             only_changes_last_changelog_block(
-                tree, tree.basis_tree(), "debian/changelog", changes
+                tree, tree.basis_tree(), "debian/changelog", list(changes)
             )
         )
 
@@ -717,7 +714,7 @@ blah (0.1) UNRELEASED; urgency=medium
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(
             only_changes_last_changelog_block(
-                tree, tree.basis_tree(), "debian/changelog", changes
+                tree, tree.basis_tree(), "debian/changelog", list(changes)
             )
         )
 
@@ -748,7 +745,7 @@ blah (0.1) unstable; urgency=medium
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(
             only_changes_last_changelog_block(
-                tree, tree.basis_tree(), "debian/changelog", changes
+                tree, tree.basis_tree(), "debian/changelog", list(changes)
             )
         )
 
@@ -780,7 +777,7 @@ blah (0.1) unstable; urgency=medium
             changes = tree.iter_changes(basis_tree)
         self.assertTrue(
             only_changes_last_changelog_block(
-                tree, tree.basis_tree(), "debian/changelog", changes
+                tree, tree.basis_tree(), "debian/changelog", list(changes)
             )
         )
 
@@ -807,7 +804,7 @@ blah (0.1) unstable; urgency=medium
             changes = tree.iter_changes(basis_tree)
             self.assertTrue(
                 only_changes_last_changelog_block(
-                    tree, basis_tree, "debian/changelog", changes
+                    tree, basis_tree, "debian/changelog", list(changes)
                 )
             )
 
@@ -860,7 +857,7 @@ blah (0.1) unstable; urgency=medium
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(
             only_changes_last_changelog_block(
-                tree, tree.basis_tree(), "debian/changelog", changes
+                tree, tree.basis_tree(), "debian/changelog", list(changes)
             )
         )
 
@@ -1025,7 +1022,7 @@ class BaseScriptFixerTests:
 
     def test_noop(self):
         fixer = self.create_fixer("print('I did not do anything')\n")
-        result = fixer.run(self.test_dir, "blah", "0.1", "buster")
+        result = fixer.run(self.test_dir, "blah", Version("0.1"), "buster")
         self.assertIsInstance(result, FixerResult)
         self.assertEqual(result.description, "I did not do anything")
 
@@ -1033,7 +1030,7 @@ class BaseScriptFixerTests:
         fixer = self.create_fixer("import os; print(os.getcwd())\n")
         os.mkdir("subdir")
         os.chdir("subdir")
-        result = fixer.run(self.test_dir, "blah", "0.1", "buster")
+        result = fixer.run(self.test_dir, "blah", Version("0.1"), "buster")
         self.assertIsInstance(result, FixerResult)
         self.assertEqual(result.description, self.test_dir)
 
@@ -1046,8 +1043,8 @@ foo()
 """
         )
         e = self.assertRaises(
-            FixerScriptFailed, fixer.run, self.test_dir, "blah", "0.1",
-            "buster")
+            FixerScriptFailed, fixer.run, self.test_dir, "blah",
+            Version("0.1"), "buster")
         self.assertEqual(e.path, fixer.script_path)
         self.assertEqual(e.returncode, 1)
         self.assertEqual(
@@ -1116,24 +1113,3 @@ class SelectFixersTests(TestCase):
                 )
             ],
         )
-
-
-class ManyResultTests(TestCase):
-    def test_empty(self):
-        result = ManyResult()
-        self.assertEqual("certain", result.minimum_success_certainty())
-
-    def test_no_certainty(self):
-        result = ManyResult()
-        result.success.append(
-            (FixerResult("Do bla", ["tag-a"], None), "summary"))
-        self.assertEqual("certain", result.minimum_success_certainty())
-
-    def test_possible(self):
-        result = ManyResult()
-        result.success.append(
-            (FixerResult("Do bla", ["tag-a"], "possible"), "summary"))
-        result.success.append(
-            (FixerResult("Do bloeh", ["tag-b"], "certain"), "summary")
-        )
-        self.assertEqual("possible", result.minimum_success_certainty())
